@@ -39,7 +39,7 @@ pub fn sp_from_c(cndc: f64, t90: f64, p: f64) -> Result<f64> {
         cndc / GSW_C3515
     };
 
-    Ok(sp_from_r(r, t90, p)?)
+    sp_from_r(r, t90, p)
 }
 
 #[cfg(test)]
@@ -82,7 +82,7 @@ mod test_sp_from_c {
                 Err(Error::Undefined) => (),
                 // S_p < 0
                 Err(Error::NegativeSalinity) => (),
-                _ => assert!(false),
+                _ => panic!("can't reach other errors"),
             }
         }
     }
@@ -131,7 +131,7 @@ mod test_c_from_sp {
         let cndc = c_from_sp(-0.1, 10.0, 100.0);
         match cndc {
             Err(Error::NegativeSalinity) => (),
-            _ => assert!(false),
+            _ => panic!("can't reach other errors"),
         }
     }
 
@@ -143,7 +143,7 @@ mod test_c_from_sp {
         let cndc = c_from_sp(42.1, 10.0, 100.0);
         match cndc {
             Err(Error::Undefined) => (),
-            _ => assert!(false),
+            _ => panic!("can't reach other errors"),
         }
     }
 }
@@ -236,6 +236,7 @@ mod test_sp_from_r {
     }
 }
 
+#[allow(clippy::manual_range_contains)]
 /// Conductivity ratio from Practical Salinity
 ///
 /// # Arguments
@@ -335,7 +336,7 @@ pub fn r_from_sp(sp: f64, t90: f64, p: f64) -> Result<f64> {
         dsp_drtx = dsp_drtx
             + A0 * 800.0 * rtx * (1.5 + 2.0 * x) / (part1 * part1)
             + B0 * ft68 * (10.0 + sqrty * (20.0 + 30.0 * sqrty)) / (part2 * part2);
-        dsp_drtx = hill_ratio * dsp_drtx;
+        dsp_drtx *= hill_ratio;
     }
 
     // One iteration through the modified Newton-Raphson method (McDougall and
@@ -380,7 +381,7 @@ pub fn r_from_sp(sp: f64, t90: f64, p: f64) -> Result<f64> {
             + A0 * 800.0 * rtxm * (1.5e0 + 2.0 * x) / (part1 * part1)
             + B0 * ft68 * (10.0 + sqrty * (20.0 + 30.0 * sqrty)) / (part2 * part2);
         let hill_ratio = hill_ratio_at_sp2(t90);
-        dsp_drtx = hill_ratio * dsp_drtx;
+        dsp_drtx *= hill_ratio;
     }
 
     // The line below is where Rtx is updated at the end of the one full
@@ -400,7 +401,7 @@ pub fn r_from_sp(sp: f64, t90: f64, p: f64) -> Result<f64> {
         let hill_ratio = hill_ratio_at_sp2(t90);
         sp_est = hill_ratio * sp_hill_raw;
     }
-    rtx = rtx - (sp_est - sp) / dsp_drtx;
+    rtx -= (sp_est - sp) / dsp_drtx;
 
     // Now go from Rtx to Rt and then to the conductivity ratio R at pressure p.
     let rt = rtx * rtx;
@@ -536,7 +537,7 @@ mod test_sp_salinometer {
                 Err(Error::Undefined) => (),
                 // S_p < 0
                 Err(Error::NegativeSalinity) => (),
-                _ => assert!(false),
+                _ => panic!("can't reach other errors"),
             }
         }
     }
